Learn R Programming

SenSrivastava (version 0.1-14)

E1.15: Stevens Experiment to compare notes against a standard (80 Db)

Description

The E1.15 data frame has 10 rows and 3 columns. Stevens (1956) asked a number of persons to compare notes of various decibel levels against a standard (80 decibels) and to assign them a loudness rating with the standard note being a 10. logy is the response variable and x the stimulus.

Usage

data(E1.15)

Arguments

concept

  • Stevens experiment to compare notes against a standard
  • regression

source

Dacey,M.F. (1983) Social science Theories and Methods I: Models of Data Evanston: Northwestern University, fromStevens (1956).

Examples

Run this code
data(E1.15)
attach(E1.15)
plot(x, logy)
abline(lm( logy ~ x, data=E1.15))
detach()

Run the code above in your browser using DataLab