Learn R Programming

SenSrivastava (version 0.1-14)

E1.19: Data on Book Prices, Pages and Type of Binding

Description

The E1.19 data frame has 20 rows and 3 columns. Compiled from the catalog of one publisher of American Government books.

Usage

data(E1.19)

Arguments

concept

  • Data on Book Prices, Pages and Type of Binding
  • regression

source

Compiled by one of the authors.

Examples

Run this code
data(E1.19)
   summary(E1.19)

Run the code above in your browser using DataLab