Learn R Programming

SenSrivastava (version 0.1-14)

E1.21: Data on Loads and Deformation of a Bar

Description

The E1.21 data frame has 24 rows and 2 columns. Data are on loads, in pounds, and corresponding deformation, in inches, of a mild steel bar, of length 8 inches and average diameter .564 inches.

Usage

data(E1.21)

Arguments

concept

  • Data on Loads and Deformation of a Bar
  • regression

source

M.R. Khavanin, Department of Mechanical Engineering, University of Illinois at Chicago.

Examples

Run this code
data(E1.21)
attach(E1.21)
plot(L, D)
detach()

Run the code above in your browser using DataLab