Learn R Programming

SenSrivastava (version 0.1-14)

E1.7: Data on Population and Number of Telephones

Description

The E1.7 data frame has 6 rows and 2 columns. The relation between population and number of telephones have been used to estimate the population in non-census years.

Usage

data(E1.7)

Arguments

concept

  • Relation between population number telephones
  • regression

source

Prof. Edwin Thomas, Department of Geography, University of Illinois at Chicago.

Examples

Run this code
data(E1.7)
attach(E1.7)
plot(RES, MAINS)
plot(sqrt(RES), sqrt(MAINS))

Run the code above in your browser using DataLab