Learn R Programming

SenSrivastava (version 0.1-14)

E10.3: Supervisor Rating Data

Description

The E10.3 data frame has 30 rows and 6 columns. This is part of a larger data set gathered for other purposes. The six variables are each composites obtained from responses to a questionare. The dependent variable y is a composite of responses towards thr respondent's supervisor and on job satisfaction. The highest possible score is 20. The predictor variables are defined below.

Usage

data(E10.3)

Arguments

concept

  • Supervisor Rating Data
  • regression

source

Sen and Srivastava (1990) Regression Analysis, Theory, Methods and Applications. Springer-verlag.

Examples

Run this code
data(E10.3)
summary(E10.3)
plot(E10.3)

Run the code above in your browser using DataLab