Learn R Programming

SenSrivastava (version 0.1-14)

E11.1: Artificially Created Data for an Example on Variable Search

Description

The E11.1 data frame has 20 rows and 5 columns.

Usage

data(E11.1)

Arguments

concept

  • Artificially Created Data for an Example on Variable Search
  • variable search
  • all subsets regression

source

Data made up by the authors.

Examples

Run this code
data(E11.1)
exleaps <- require("leaps", quietly=TRUE)
if (exleaps) {
   E11.1.m1 <- regsubsets(y ~x.1+x.2+x.3+x.4, data=E11.1)
   summary(E11.1.m1)
   plot(E11.1.m1)
}

Run the code above in your browser using DataLab