Learn R Programming

SenSrivastava (version 0.1-14)

E2.11: Demographic Data for the 50 States of the U.S.

Description

The E2.11 data frame has 50 rows and 27 columns, this combines exhibits E2.10 and E2.11 in the book. The data are for 1980 except as noted.

Usage

data(E2.11)

Arguments

concept

Demographic Data for the 50 States of the U.S.

source

Compiled by Prof. Siim Soot, Department of Geography, University of Illinois at Chicago, from Statistical Abstract of the United States, 1981, U.S. Bureau of the Census, Washington, D.C.

Examples

Run this code
data(E2.11)
summary(E2.11)

Run the code above in your browser using DataLab