Learn R Programming

SenSrivastava (version 2015.6.25)

E2.2: Data on House Prices

Description

The E2.2 data frame has 26 rows and 14 columns, data on house prices in different zones of Chicago.

Usage

data(E2.2)

Arguments

Format

This data frame contains the following columns:

Price

a numeric vector, selling price of house in thousands of dollars.

BDR

a numeric vector, number of bedrooms.

FLR

a numeric vector, floor space in sq. feet.

FP

a numeric vector, number of fireplaces.

RMS

a numeric vector, number of rooms.

ST

a numeric vector, storm windows (1 present, 0 absent).

LOT

a numeric vector, front footage of lot in feet.

TAX

a numeric vector, annual taxes.

BTH

a numeric vector, number of bathrooms.

CON

a numeric vector, construction (0 if frame, 1 if brick).

GAR

a numeric vector, garage size (0=no garage, 10 1 auto garage, etc.).

CDN

a numeric vector, condition (1=needs work, 0 otherwise).

L1

a numeric vector, indicator for zone A.

L2

a numeric vector, indicator for zone B.

Examples

Run this code
data(E2.2)
summary(E2.2)

Run the code above in your browser using DataLab