powered by
The E2.8 data frame has 17 rows and 4 columns, data for 17 factories in Shanghai.
E2.8
data(E2.8)
This data frame contains the following columns:
a numeric vector, per capita output in Chinese Yuan.
a numeric vector, number of workers in the factory.
a numeric vector, land area of the factory in sq. meters per worker.
a numeric vector, investments in Yuan per worker.
data(E2.8) summary(E2.8)
Run the code above in your browser using DataLab