Learn R Programming

SenSrivastava (version 0.1-14)

E2.9: Data on Capital, Labour and Value Added for Three Sectors

Description

The E2.9 data frame has 15 rows and 10 columns. The three sectors are "20": Food and kindred products, "36": Equipment and supplies and "37": Transportation equipment.

Usage

data(E2.9)

Arguments

concept

  • Data on Capital, Labour and Value Added for Three Sectors
  • regression

source

Dr. Phillip Israelovich of the Federal Reserve Bank.

Examples

Run this code
data(E2.9)
summary(E2.9)

Run the code above in your browser using DataLab