Learn R Programming

SenSrivastava (version 0.1-14)

E3.7: Data on Oxygen Demand in Dairy Wastes

Description

The E3.7 data frame has 20 rows and 7 columns.

Usage

data(E3.7)

Arguments

concept

  • Data on Oxygen Demand in Dairy Wastes
  • regression

source

Moore (1975) Total Biochemical Oxygen Demand of Animal Manures. Ph. D. thesis, University of Minnesota, Dept. of Agricultural Engineering.

Details

This is data from an experiment to construct a model for total oxygen demand in dairy wastes as a dunction of five laboratory measurements. Data were collected on samples kept in suspension in water in a laboratory for 220 days. All observations given here were taken on the same sample over time, so are probably dependent.

Examples

Run this code
data(E3.7)
summary(E3.7)

Run the code above in your browser using DataLab