Learn R Programming

SenSrivastava (version 0.1-14)

E3.8: Map reading Test scores and Route Finding Scores

Description

The E3.8 data frame has 20 rows and 3 columns. 20 student volunteers where given a map reading test and a test of route finding on transit maps.

Usage

data(E3.8)

Arguments

concept

Map reading Test scores and Route Finding Scores

source

Preof. Siim Soot, Department of Geography, University of Illinois at Chicago.

Examples

Run this code
data(E3.8)
summary(E3.8)

Run the code above in your browser using DataLab