powered by
The E3.9 data frame has 18 rows and 4 columns. All the observations are for the same person.
E3.9
data(E3.9)
This data frame contains the following columns:
a numeric vector, cardiac output.
a numeric vector, carbon dioxide level in the blood.
a numeric vector, blood flow velocity in the brain.
a factor with levels no with, Aminophylline used or not. The hypothesis is that aminophylline retards blood flow.
no
with
data(E3.9) summary(E3.9)
Run the code above in your browser using DataLab