Learn R Programming

SenSrivastava (version 0.1-14)

E4.10: Votes from Chicago's Twenty-second Ward by Precinct

Description

The E4.10 data frame has 27 rows and 7 columns.

Usage

data(E4.10)

Arguments

concept

  • Votes from Chicago's Twenty-second Ward by Precinct
  • regression

source

Ray Flores, The Latino Institute, Chicago.

Details

Note that the votes for the three candidates may not add to the total turnout because of write-in votes, spoilt ballots, etc.

Examples

Run this code
data(E4.10)
summary(E4.10)

Run the code above in your browser using DataLab