Learn R Programming

SenSrivastava (version 0.1-14)

E4.12: Time taken by Professional Dieticians and Interns for Four Patient Contact Activities

Description

The E4.12 data frame has 24 rows and 6 columns. Each row is the activities and time taken by one dietician.

Usage

data(E4.12)

Arguments

concept

  • Time taken by Professional Dieticians and Interns for Four Patient Contact Activities
  • regression

source

The data where made available to one of the authors by a student.

Examples

Run this code
m1 <- lm(Time ~ SC+DC+MR+TR-1, data=E4.12, subset=Dietician=="Prof")
summary(m1)

Run the code above in your browser using DataLab