Learn R Programming

SenSrivastava (version 0.1-14)

E4.4: Measures of Quality for Agencies Delivering Transportation for the Elderly and the Handicapped

Description

The E4.4 data frame has 40 rows and 3 columns.

Usage

data(E4.4)

Arguments

concept

  • Measures of Quality for Agencies Delivering Transportation for the Elderly and the Handicapped
  • regression

source

Slightly modified version of data supplied by Ms. Claire McKnight of the Department of Civil Engineering, City University of New York.

Details

The quality data, QUAL, is constructed from questionares given to users of such services in the state of Illinois. Multiple services in the state of Illinois was scored using this method. The indicator variables was constructed to give first (X.1) a comparison between private and public services, then (X.2) a comparison between private not-for-profit and private for profit services.

Examples

Run this code
data(E4.4)
summary(E4.4)

Run the code above in your browser using DataLab