Learn R Programming

SenSrivastava (version 0.1-14)

E6.1: Data on Automobile Speed and Distance Covered to Come to a Standstill after Breaking

Description

The E6.1 data frame has 62 rows and 2 columns.

Usage

data(E6.1)

Arguments

concept

  • Data on Automobile Speed and Distance Covered to Come to a Standstill after Breaking
  • regression

source

From Ezekiel,M. and F. A. Fox, Methods of Correlation and Regression Analysis. Copyright 1959 John Wiley and Sons, Inc.

Examples

Run this code
data(E6.1)
attach(E6.1)
plot(sp., d.)
detach()

Run the code above in your browser using DataLab