Learn R Programming

SenSrivastava (version 2015.6.25.1)

E6.11: Heights of Fathers and Sons

Description

The E6.11 data frame has 12 rows and 3 columns.

Usage

data(E6.11)

Arguments

Format

This data frame contains the following columns:

Height.Father

a numeric vector, height of father to the nearest inch.

Aver.Height.Son

a numeric vector, average heights of sons.

No.Fathers

a numeric vector, number of fathers in each group.

Examples

Run this code
data(E6.11)
summary(E6.11)

Run the code above in your browser using DataLab