- POP
a numeric vector, population of area where service where operating.
- AR
a numeric vector, area of the place where service where provided.
- RDR
a numeric vector, number of riders using the system.
- HR
a numeric vector, hours of operation.
- VH
a numeric vector, number of vehicles in operation.
- F
a numeric vector, the fare used.
- IND
a numeric vector, a composite index, 1 when several ridership enhancing features
where present, and 0 elsewhere.