Learn R Programming

SenSrivastava (version 0.1-14)

E7.2: Prices of Crude Oil, Natural Gas, Bituminous Coal and Lignite, and Anthracite by Year.

Description

The E7.2 data frame has 32 rows and 5 columns. Prices are in 1972 cents (U.S) by 1000 BTU.

Usage

data(E7.2)

Arguments

concept

  • Prices of Crude Oil, Natural Gas, Bituminous Coal and Lignite, and Anthracite by Year.
  • regression

source

Darrel Sala, Institute of Gas Technology, Chicago.

Examples

Run this code
data(E7.2)
summary(E7.2)

Run the code above in your browser using DataLab