Learn R Programming

SenSrivastava (version 0.1-14)

E7.3: Data on Intake/Output Ratio

Description

The E7.3 data frame has 19 rows and 6 columns. It gives the ratios u of fluid intake to urine output over five consecutive 8-hour periods for 19 babies divided in a control and treatment group.

Usage

data(E7.3)

Arguments

concept

  • Data on Intake/Output Ratio
  • regression

source

Rama Bhat, M.D., Department of Pediatrics, University of Illinoi at Chicago. This data is part of a larger data set.

Examples

Run this code
data(E7.3)
summary(E7.3)

Run the code above in your browser using DataLab