Learn R Programming

SenSrivastava (version 0.1-14)

E7.4: Data on PCO2 and Cerebral Blood Flow for Five Regions of the Brain of five Chimpanzees

Description

The E7.4 data frame has 5 rows and 11 columns. Five baby chimpanzees were injected with a heavy dose of HIV infection. After six months, the radio-active microsphere technique was used to measure brain blood flow in ml per 100 grams of brain tissue, from five regions of the brain. The partial pressure of carbon dioxide in millimeters of mercury was also obtained.

Usage

data(E7.4)

Arguments

concept

  • Data on PCO2 and Cerebral Blood Flow for Five Regions of the Brain of five Chimpanzees
  • regression

source

Tonse Raju, M.D. Department of pediatrics, University of Illinois at Chicago.

Examples

Run this code
data(E7.4)
summary(E7.4)

Run the code above in your browser using DataLab