Learn R Programming

SenSrivastava (version 0.1-14)

E7.5: Data on Static Weights and Weight in Motion of Trucks

Description

The E7.5 data frame has 26 rows and 6 columns.

Usage

data(E7.5)

Arguments

concept

  • Data on Static Weights and Weight in Motion of Trucks
  • regression

source

Saleh Mumayiz, Urban Transportation Center, University of Illinois at Chicago, who compiled the data from a data set provided by the Illinois Department of Transportation.

Details

Trucks can be weighted by two methods. In one, a truck needs to go into a weighting station and each axle is weighted by conventional means. The other is newer and a somewhat experimental method where a thin pad is placed on the highway and axles are weighted as trucks pass over it. Former weight are called static weights (sw) while later are called weights in motion (wim).

Examples

Run this code
data(E7.5)
summary(E7.5)
plot(E7.5)

Run the code above in your browser using DataLab