Learn R Programming

SenSrivastava (version 0.1-14)

E7.6: Community Area Data for the North Part of the City of Chicago

Description

The E7.6 data frame has 34 rows and 5 columns.

Usage

data(E7.6)

Arguments

concept

Community Area Data for the North Part of the City of Chicago

source

Data set were constructed by Prof. Siim Soot, Dept. of Geography, University of Illinois at Chicago.

See Also

E7.7, which is the adjacency matrix for the 34 areas.

Examples

Run this code
data(E7.6)
summary(E7.6)

Run the code above in your browser using DataLab