Learn R Programming

SenSrivastava (version 2015.6.25)

E8.13: Florida Cumulus Experiment Data

Description

The E8.13 data frame has 20 rows and 7 columns, giving data on the effects of cloud seeding by silver iodide crystals on precipitation. Each data point is one day.

Usage

data(E8.13)

Arguments

Format

This data frame contains the following columns:

A

a factor with levels NoSeed Seed

T

a numeric vector, number of days after the first day of the experiment.

S

a numeric vector, relates to heights of clouds.

C

a numeric vector, percentage of clode cover in the experimental area.

P

a numeric vector, total rainfall in the study area one hour before seeding (in $10^7$ cubic meters).

E

a factor with levels Moving Stationary , indicating if the radar echo was mowing or not.

y

a numeric vector, the response, natural logarithm of precipitation in the target area in a 6-hour period (in $10^7$ cubic meters).

Examples

Run this code
data(E8.13)
summary(E8.13)
plot(E8.13)

Run the code above in your browser using DataLab