Learn R Programming

SenSrivastava (version 2015.6.25)

E9.11: Data on Transit Privatization

Description

The E9.11 data frame has 17 rows and 10 columns.

Usage

data(E9.11)

Arguments

Format

This data frame contains the following columns:

V1

a numeric vector, average capacity of buses in service.

V2

a numeric vector, ratio of buses in use during non-peak periods to those in use in peak periods.

V3

a numeric vector, average speed.

V4

a numeric vector, vehicle-miles contracted.

V5

a numeric vector, distance of center from metroploitan area.

V6

a numeric vector, population of metropolitan area.

V7

a numeric vector, percentage of work trips in the metropolitan area that are made by transit.

V8

a numeric vector, Buses owned by sponsor / buses owned by contractor

V9

a numeric vector, per capita income for metropolitan area.

PCS

a numeric vector, per cent savings that occurred when some transit lines was given to private companies.

Examples

Run this code
data(E9.11)
summary(E9.11)
plot(E9.11)

Run the code above in your browser using DataLab