Learn R Programming

SenSrivastava (version 0.1-14)

E9.18: Data Travel Times and Usage for Automobiles and Public Transportation

Description

The E9.18 data frame has 51 rows and 4 columns.

Usage

data(E9.18)

Arguments

concept

  • Data Travel Times and Usage for Automobiles and Public Transportation
  • regression

source

Selected by Robert Drozd from Census (US) Urban Transportation Planning Package, for the Chicago area.

Details

Travel times modified by one of the authors to reflect the cost of parking. For downtown zones (Chicago) this amounted to about 60 minutes.

Examples

Run this code
data(E9.18)
summary(E9.18)
plot(E9.18)

Run the code above in your browser using DataLab