Learn R Programming

SenSrivastava (version 0.1-14)

E9.8: Data on monthly rent, annual income and househould size

Description

The E9.8 data frame has 27 rows and 3 columns.

Usage

data(E9.8)

Arguments

concept

  • Data on monthly rent, annual income and househould size
  • regression

source

Selected by one of the authors from a much larger data set, collected from several sources about 20 years ago.

Details

Example 9.8 in Sen and Srivastava, page 201.

Examples

Run this code
data(E9.8)
attach(E9.8)
E9.8.m1 <- lm(R ~ I + S, data=E9.8)
summary(E9.8.m1)
plot(I, resid(E9.8.m1, type="partial")[,"I"])
plot(S, resid(E9.8.m1, type="partial")[,"S"])
detach()

Run the code above in your browser using DataLab