powered by
The Ec.8 data frame has 112 rows and 5 columns.
Ec.8
data(Ec.8)
This data frame contains the following columns:
a character vector, containing country of origen of applicant.
a numeric vector, number of successful applications.
a numeric vector, number of denied applications.
a numeric vector, 1 if country is considered hostile to the U.S., 0 en other case.
a numeric vector, 1 if country is European or mainly inhabited by people of european descent.
data(Ec.8) summary(Ec.8) attach(Ec.8) Ec.8.m1 <- glm(cbind(APR, DEN) ~ E + H, data=Ec.8, family=binomial) summary(Ec.8.m1) detach()
Run the code above in your browser using DataLab