Learn R Programming

SenSrivastava (version 0.1-14)

Ex4.4: Data on Effects of Air Pollution on Interpersonal Attraction

Description

The Ex4.4 data frame has 24 rows and 3 columns. An experiment was conducted to examine the effects of air pollution on interpersonal attraction. Twenty-four subjects were each placed with a stranger for a 15-minute period in a room which was either odor free or contaminated with ammonium sulfide. The stranger came from a culture which was similar or dissimilar to that of the subject. At the end of the encounter, each subject was asked to assess his degree of attraction towards the stranger on a likert scale of 1--10 with 10 indicating strong attraction.

Usage

data(Ex4.4)

Arguments

concept

Data on Effects of Air Pollution on Interpersonal Attraction

source

The full data set is given in Srivastava and Carter (1983).

Examples

Run this code
data(Ex4.4)
summary(Ex4.4)
plot(Ex4.4)

Run the code above in your browser using DataLab