Learn R Programming

SenSrivastava (version 2015.6.25)

E1.15: Stevens Experiment to compare notes against a standard (80 Db)

Description

The E1.15 data frame has 10 rows and 3 columns. Stevens (1956) asked a number of persons to compare notes of various decibel levels against a standard (80 decibels) and to assign them a loudness rating with the standard note being a 10. logy is the response variable and x the stimulus.

Usage

data(E1.15)

Arguments

Format

This data frame contains the following columns:

x

a numeric vector, the stimulus.

y

a numeric vector, the median response at x

logy

a numeric vector, the log of y.

Examples

Run this code
data(E1.15)
attach(E1.15)
plot(x, logy)
abline(lm( logy ~ x, data=E1.15))
detach()

Run the code above in your browser using DataLab