Learn R Programming

SenSrivastava (version 2015.6.25)

E1.18: Data on Simsbury Marriages

Description

The E1.18 data frame has 8 rows and 3 columns with data on the number of marriages (ma) that occurred between residents of each of 8 annular zones and residents of Simsbury, Connecticut, for the period 1930--39. The number of residents of each zone is given as pop and the midpoint of distance between Simsbury and the band is given as d.

Usage

data(E1.18)

Arguments

Format

This data frame contains the following columns:

d

a numeric vector, distance between Simsbury and midpoint of annular zone.

pop

a numeric vector, population of annular zone.

ma

a numeric vector, number of marriages.

Examples

Run this code
data(E1.18)
summary(E1.18)

Run the code above in your browser using DataLab