Learn R Programming

SenSrivastava (version 2015.6.25)

E1.19: Data on Book Prices, Pages and Type of Binding

Description

The E1.19 data frame has 20 rows and 3 columns. Compiled from the catalog of one publisher of American Government books.

Usage

data(E1.19)

Arguments

Format

This data frame contains the following columns:

Price

a numeric vector, price of book.

P

a numeric vector, number of pages of book.

B

a factor with levels c p, c is cloth and p is paperback.

Examples

Run this code
   data(E1.19)
   summary(E1.19)

Run the code above in your browser using DataLab