powered by
The E1.19 data frame has 20 rows and 3 columns. Compiled from the catalog of one publisher of American Government books.
E1.19
data(E1.19)
This data frame contains the following columns:
a numeric vector, price of book.
a numeric vector, number of pages of book.
a factor with levels c p, c is cloth and p is paperback.
c
p
data(E1.19) summary(E1.19)
Run the code above in your browser using DataLab