Learn R Programming

SenSrivastava (version 2015.6.25)

E1.21: Data on Loads and Deformation of a Bar

Description

The E1.21 data frame has 24 rows and 2 columns. Data are on loads, in pounds, and corresponding deformation, in inches, of a mild steel bar, of length 8 inches and average diameter .564 inches.

Usage

data(E1.21)

Arguments

Format

This data frame contains the following columns:

L

a numeric vector, load, in pounds.

D

a numeric vector, corresponding deformation, in inches.

Examples

Run this code
data(E1.21)
attach(E1.21)
plot(L, D)
detach()

Run the code above in your browser using DataLab