Learn R Programming

SenSrivastava (version 2015.6.25)

E1.7: Data on Population and Number of Telephones

Description

The E1.7 data frame has 6 rows and 2 columns. The relation between population and number of telephones have been used to estimate the population in non-census years.

Usage

data(E1.7)

Arguments

Format

This data frame contains the following columns:

RES

a numeric vector, number of residents.

MAINS

a numeric vector, number of telephones.

Examples

Run this code
data(E1.7)
attach(E1.7)
plot(RES, MAINS)
plot(sqrt(RES), sqrt(MAINS))

Run the code above in your browser using DataLab