powered by
The E1.7 data frame has 6 rows and 2 columns. The relation between population and number of telephones have been used to estimate the population in non-census years.
E1.7
data(E1.7)
This data frame contains the following columns:
a numeric vector, number of residents.
a numeric vector, number of telephones.
data(E1.7) attach(E1.7) plot(RES, MAINS) plot(sqrt(RES), sqrt(MAINS))
Run the code above in your browser using DataLab