- Price
a numeric vector, selling price of house in thousands of dollars.
- BDR
a numeric vector, number of bedrooms.
- FLR
a numeric vector, floor space in sq. feet.
- FP
a numeric vector, number of fireplaces.
- RMS
a numeric vector, number of rooms.
- ST
a numeric vector, storm windows (1 present, 0 absent).
- LOT
a numeric vector, front footage of lot in feet.
- TAX
a numeric vector, annual taxes.
- BTH
a numeric vector, number of bathrooms.
- CON
a numeric vector, construction (0 if frame, 1 if brick).
- GAR
a numeric vector, garage size (0=no garage, 10 1 auto garage, etc.).
- CDN
a numeric vector, condition (1=needs work, 0 otherwise).
- L1
a numeric vector, indicator for zone A.
- L2
a numeric vector, indicator for zone B.