Learn R Programming

SenSrivastava (version 2015.6.25)

E2.8: Data on per Capita Output of Workers in Shanghai

Description

The E2.8 data frame has 17 rows and 4 columns, data for 17 factories in Shanghai.

Usage

data(E2.8)

Arguments

Format

This data frame contains the following columns:
Output
a numeric vector, per capita output in Chinese Yuan.
SI
a numeric vector, number of workers in the factory.
SP
a numeric vector, land area of the factory in sq. meters per worker.
I
a numeric vector, investments in Yuan per worker.

Prof. Zhang Tingwei of Tongji University, Shanghai.

Examples

Run this code
   data(E2.8)
   summary(E2.8)

Run the code above in your browser using DataLab