- Day
a numeric vector, day of measurement, all measurements are on
the same sample.
- x.1
a numeric vector, biological oxygen demand, mg/liter.
- x.2
a numeric vector, total Kjeldahl nitrogen, mg/liter.
- x.3
a numeric vector, total solids, mg/liter.
- x.4
a numeric vector, total volatile solids, a component of x.3,
in mg/liter.
- x.5
a numeric vector, chemical oxygen demand, mg/liter.
- y
a numeric vector, the response, log of oxygen demand, mg oxygen per minute.