powered by
The E3.8 data frame has 20 rows and 3 columns. 20 student volunteers where given a map reading test and a test of route finding on transit maps.
E3.8
data(E3.8)
This data frame contains the following columns:
a numeric vector, ability to find routes to a given destination on a transit route map where scored y.
y
a numeric vector, scores on a map reading ability test.
a factor with levels Non.users Users, users and non-users of transit.
Non.users
Users
data(E3.8) summary(E3.8)
Run the code above in your browser using DataLab