Learn R Programming

SenSrivastava (version 2015.6.25)

E3.8: Map reading Test scores and Route Finding Scores

Description

The E3.8 data frame has 20 rows and 3 columns. 20 student volunteers where given a map reading test and a test of route finding on transit maps.

Usage

data(E3.8)

Arguments

Format

This data frame contains the following columns:
y
a numeric vector, ability to find routes to a given destination on a transit route map where scored y.
sc
a numeric vector, scores on a map reading ability test.
Use
a factor with levels Non.users Users, users and non-users of transit.

Preof. Siim Soot, Department of Geography, University of Illinois at Chicago.

Examples

Run this code
data(E3.8)
summary(E3.8)

Run the code above in your browser using DataLab