E3.9: Blood Velocity Data
Description
The E3.9 data frame has 18 rows and 4 columns.
All the observations are for the same person.
Format
This data frame contains the following columns:
- x.1
-
a numeric vector, cardiac output.
- x.2
-
a numeric vector, carbon dioxide level in the blood.
- y
-
a numeric vector, blood flow velocity in the brain.
- Aminophylline
-
a factor with levels
no
with, Aminophylline used or not. The hypothesis is that
aminophylline retards blood flow.
Tonse Raju, M.D., Department of Neonatology, University of Illinois
at Chicago.