Learn R Programming

SenSrivastava (version 2015.6.25)

E4.10: Votes from Chicago's Twenty-second Ward by Precinct

Description

The E4.10 data frame has 27 rows and 7 columns.

Usage

data(E4.10)

Arguments

Format

This data frame contains the following columns:
Pr.
a numeric vector, precinct number.
LATV
a numeric vector, number of latin voters.
NONLV
a numeric vector, number of non-latin voters.
TURNOUT
a numeric vector, total number of votes cast.
GARCIA
a numeric vector, number of votes for Garcia.
MARTINEZ
a numeric vector, number of votes for Martinez.
YANEZ
a numeric vector, number of votes for Yanez.

Ray Flores, The Latino Institute, Chicago.

Details

Note that the votes for the three candidates may not add to the total turnout because of write-in votes, spoilt ballots, etc.

Examples

Run this code
data(E4.10)
summary(E4.10)

Run the code above in your browser using DataLab