powered by
The E4.12 data frame has 24 rows and 6 columns. Each row is the activities and time taken by one dietician.
E4.12
data(E4.12)
This data frame contains the following columns:
a numeric vector, sum of time taken for all activities.
a numeric vector, number of patient contacts for screening.
a numeric vector, number of patient contacts for diet class.
a numeric vector, number of patient contacts for meal rounds.
a numeric vector, number of patient contacts for team rounds.
a factor with levels Intern Prof, dietician is professional or intern.
Intern
Prof
m1 <- lm(Time ~ SC+DC+MR+TR-1, data=E4.12, subset=Dietician=="Prof") summary(m1)
Run the code above in your browser using DataLab