Learn R Programming

SenSrivastava (version 2015.6.25)

E4.12: Time taken by Professional Dieticians and Interns for Four Patient Contact Activities

Description

The E4.12 data frame has 24 rows and 6 columns. Each row is the activities and time taken by one dietician.

Usage

data(E4.12)

Arguments

Format

This data frame contains the following columns:
Time
a numeric vector, sum of time taken for all activities.
SC
a numeric vector, number of patient contacts for screening.
DC
a numeric vector, number of patient contacts for diet class.
MR
a numeric vector, number of patient contacts for meal rounds.
TR
a numeric vector, number of patient contacts for team rounds.
Dietician
a factor with levels Intern Prof, dietician is professional or intern.

The data where made available to one of the authors by a student.

Examples

Run this code
m1 <- lm(Time ~ SC+DC+MR+TR-1, data=E4.12, subset=Dietician=="Prof")
summary(m1)

Run the code above in your browser using DataLab