The quality data, QUAL, is constructed from questionares given
to users of such services in the state of Illinois. Multiple services
in the state of Illinois was scored using this method. The indicator variables
was constructed to give first (X.1) a comparison between private
and public services, then (X.2) a comparison between private
not-for-profit and private for profit services.