Learn R Programming

SenSrivastava (version 2015.6.25.1)

E6.1: Data on Automobile Speed and Distance Covered to Come to a Standstill after Breaking

Description

The E6.1 data frame has 62 rows and 2 columns.

Usage

data(E6.1)

Arguments

Format

This data frame contains the following columns:

d.

a numeric vector, distance covered to come to a standstill after breaking.

sp.

a numeric vector, speed before breaking.

Examples

Run this code
data(E6.1)
attach(E6.1)
plot(sp., d.)
detach()

Run the code above in your browser using DataLab