powered by
The E6.11 data frame has 12 rows and 3 columns.
E6.11
data(E6.11)
This data frame contains the following columns:
a numeric vector, height of father to the nearest inch.
a numeric vector, average heights of sons.
a numeric vector, number of fathers in each group.
data(E6.11) summary(E6.11)
Run the code above in your browser using DataLab