E6.11: Heights of Fathers and Sons
Description
The E6.11 data frame has 12 rows and 3 columns.
Format
This data frame contains the following columns:
- Height.Father
-
a numeric vector, height of father to the nearest inch.
- Aver.Height.Son
-
a numeric vector, average heights of sons.
- No.Fathers
-
a numeric vector, number of fathers in each group.
dacey (1983, Ch. 1) from McNemar (1969, p. 130), Psycological Statistics.