Learn R Programming

SenSrivastava (version 2015.6.25)

E7.2: Prices of Crude Oil, Natural Gas, Bituminous Coal and Lignite, and Anthracite by Year.

Description

The E7.2 data frame has 32 rows and 5 columns. Prices are in 1972 cents (U.S) by 1000 BTU.

Usage

data(E7.2)

Arguments

Format

This data frame contains the following columns:

year

a numeric vector, year of observation.

Oil

a numeric vector, price of oil.

Gas

a numeric vector, price of Gas.

Bit.

a numeric vector, price of Bituminous Coal and Lignite.

Anth.

a numeric vector, price of Anthracite.

Examples

Run this code
data(E7.2)
summary(E7.2)

Run the code above in your browser using DataLab