Learn R Programming

SenSrivastava (version 2015.6.25)

E7.5: Data on Static Weights and Weight in Motion of Trucks

Description

The E7.5 data frame has 26 rows and 6 columns.

Usage

data(E7.5)

Arguments

Format

This data frame contains the following columns:

sw.1

a numeric vector, static weight of axle 1.

wim.1

a numeric vector, weight in motion of axle 1.

sw.23

a numeric vector, static weight of axles 2--3.

wim.23

a numeric vector, weight in motion of axles 2--3.

sw.45

a numeric vector, static weight of axles 4--5.

wim.45

a numeric vector, weight in motion of axles 4--5.

Details

Trucks can be weighted by two methods. In one, a truck needs to go into a weighting station and each axle is weighted by conventional means. The other is newer and a somewhat experimental method where a thin pad is placed on the highway and axles are weighted as trucks pass over it. Former weight are called static weights (sw) while later are called weights in motion (wim).

Examples

Run this code
data(E7.5)
summary(E7.5)
plot(E7.5)

Run the code above in your browser using DataLab