- sw.1
a numeric vector, static weight of axle 1.
- wim.1
a numeric vector, weight in motion of axle 1.
- sw.23
a numeric vector, static weight of axles 2--3.
- wim.23
a numeric vector, weight in motion of axles 2--3.
- sw.45
a numeric vector, static weight of axles 4--5.
- wim.45
a numeric vector, weight in motion of axles 4--5.