Learn R Programming

SenSrivastava (version 2015.6.25)

E7.6: Community Area Data for the North Part of the City of Chicago

Description

The E7.6 data frame has 34 rows and 5 columns.

Usage

data(E7.6)

Arguments

Format

This data frame contains the following columns:

Area.Name

a character vector, name of area.

PB

a numeric vector, percentage of population which are black.

PS

a numeric vector, percentage of population which are spanish speaking.

PA

a numeric vector, percentage of population over 65.

Income

a numeric vector, median family income for each area.

See Also

E7.7, which is the adjacency matrix for the 34 areas.

Examples

Run this code
data(E7.6)
summary(E7.6)

Run the code above in your browser using DataLab