powered by
The E7.6 data frame has 34 rows and 5 columns.
E7.6
data(E7.6)
This data frame contains the following columns:
a character vector, name of area.
a numeric vector, percentage of population which are black.
a numeric vector, percentage of population which are spanish speaking.
a numeric vector, percentage of population over 65.
a numeric vector, median family income for each area.
E7.7, which is the adjacency matrix for the 34 areas.
E7.7
data(E7.6) summary(E7.6)
Run the code above in your browser using DataLab