- A
a factor with levels
NoSeed
Seed
- T
a numeric vector, number of days after the first day of the experiment.
- S
a numeric vector, relates to heights of clouds.
- C
a numeric vector, percentage of clode cover in the experimental area.
- P
a numeric vector, total rainfall in the study area one hour before seeding
(in $10^7$ cubic meters).
- E
a factor with levels
Moving
Stationary , indicating if the radar echo was mowing or not.
- y
a numeric vector, the response, natural logarithm of precipitation in the
target area in a 6-hour period (in $10^7$ cubic meters).