Learn R Programming

SenSrivastava (version 2015.6.25)

E9.18: Data Travel Times and Usage for Automobiles and Public Transportation

Description

The E9.18 data frame has 51 rows and 4 columns.

Usage

data(E9.18)

Arguments

Format

This data frame contains the following columns:

t.a

a numeric vector, travel time by car, in tenth of minutes.

t.r

a numeric vector, travel time by public transportation, in tenth of minutes.

m.a

a numeric vector, number of those who used a car or van either as driver or passenger.

m.r

a numeric vector, number of people using any kind of public transportation.

Details

Travel times modified by one of the authors to reflect the cost of parking. For downtown zones (Chicago) this amounted to about 60 minutes.

Examples

Run this code
data(E9.18)
summary(E9.18)
plot(E9.18)

Run the code above in your browser using DataLab